<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'کەسی هامڕا چە یەکەمین سەردانیکەردەو نۋیسنگاو پەشتۊSPIP .خزمەتو بەکاربەرا کەرۊ',
	'compagnon_nom' => 'ھامڕا',
	'compagnon_slogan' => 'ڕانیشاندەرو یەکەمین ھەنگامەکا چنی SPIP',
];
